@@ -5,7 +5,6 @@
  *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "waylandoutputmanagement.h"
-#include "waylandconfig.h"
 #include <QDebug>
 
 namespace KScreen
@@ -37,21 +36,32 @@ void WaylandOutputConfiguration::kde_output_configuration_v2_failed()
     Q_EMIT failed();
 }
 
-WaylandPrimaryOutput::WaylandPrimaryOutput(struct ::wl_registry *registry, int id, int version)
-    : QObject()
-    , QtWayland::kde_primary_output_v1(registry, id, version)
+WaylandOutputOrder::WaylandOutputOrder(struct ::wl_registry *registry, int id, int version)
+    : QtWayland::kde_output_order_v1(registry, id, version)
 {
 }
 
-WaylandPrimaryOutput::~WaylandPrimaryOutput()
+WaylandOutputOrder::~WaylandOutputOrder()
 {
-    if (kde_primary_output_v1_get_version(object()) >= KDE_PRIMARY_OUTPUT_V1_DESTROY_SINCE_VERSION) {
-        destroy();
-    }
+    destroy();
 }
 
-void WaylandPrimaryOutput::kde_primary_output_v1_primary_output(const QString &outputName)
+QList<QString> WaylandOutputOrder::order() const
 {
-    Q_EMIT primaryOutputChanged(outputName);
+    return m_outputOrder;
+}
+
+void WaylandOutputOrder::kde_output_order_v1_output(const QString &output_name)
+{
+    m_pendingOutputOrder.push_back(output_name);
+}
+
+void WaylandOutputOrder::kde_output_order_v1_done()
+{
+    m_outputOrder = m_pendingOutputOrder;
+    Q_EMIT outputOrderChanged(m_pendingOutputOrder);
+    m_pendingOutputOrder.clear();
 }
 }
+
+#include "moc_waylandoutputmanagement.cpp"
