@@ -11,7 +11,8 @@
 #include <QLoggingCategory>
 #include <QSize>
 
-#include "../xcbwrapper.h"
+#include <xcb/randr.h>
+#include <xcb/xcb.h>
 
 class QRect;
 class QTimer;
@@ -22,7 +23,7 @@ class XRandRConfig;
 class XRandR : public KScreen::AbstractBackend
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kf5.kscreen.backends.xrandr")
+    Q_PLUGIN_METADATA(IID "org.kf6.kscreen.backends.xrandr")
 
 public:
     explicit XRandR();
