@@ -3,8 +3,7 @@
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#ifndef WAYLANDDPMSHELPER_H
-#define WAYLANDDPMSHELPER_H
+#pragma once
 
 #include "abstractdpmshelper_p.h"
 
@@ -22,9 +21,5 @@ public:
     void trigger(KScreen::Dpms::Mode mode, const QList<QScreen *> &screens) override;
 
 private:
-    void blockUntilSupported() override;
-
     DpmsManager *m_dpmsManager = nullptr;
 };
-
-#endif
